module CURIC::Gestrue
  class SVGConverter
    attr_reader :dialog
    attr_accessor :disable_ui

    @disable_ui = false

    def initialize(commands)
      @commands = commands

      show_dialog unless @commands.empty?
    end

    def show_dialog
      if @dialog&.visible?
        @dialog.bring_to_front
      else
        toggle_dialog
      end
    end

    def toggle_dialog
      return @dialog.close if @dialog&.visible?

      @dialog = UI::HtmlDialog.new(
        dialog_title: 'SVG Converter',
        # preferences_key: "#{PLUGIN_NAME}.dialog.#{PLUGIN_ID}.SVGConverter",
        scrollable: false,
        resizable: true,
        width: 175,
        height: 100,
        min_width: 100,
        max_width: 300,
        max_height: 200,
        min_height: 100,
        left: 100,
        top: 100,
        style: UI::HtmlDialog::STYLE_UTILITY
      )

      path = File.join(File.dirname(__FILE__), 'ui')
      html = File.join(path, 'html/svg_convert.html')
      @dialog.set_file(html)

      add_action_callback

      @dialog.show
    end

    def add_action_callback
      @dialog.add_action_callback('ready') do |_action, _width, _height|
        @dialog.execute_script("app.svgImageCommands = (#{@commands.to_json})")

        # # Check if dialog outside of screen
        # position = @dialog.get_position
        # view = Sketchup.active_model.active_view
        # @dialog.center if position.x > view.vpwidth || position.y > view.vpheight
      end

      @dialog.add_action_callback('svgToPng') do |_a, cmd, data|
        CURIC::Gesture::GestureUI.svg_to_png(cmd, data)
      end 

      @dialog.add_action_callback('done') { 
        Sketchup.active_model.active_view.invalidate
        @dialog.close 
      }
    end
  end
end
